@@ -16,7 +16,7 @@
 #' @param method method for selecting shrinkage parameter lambda, either "BIC" (default) or "AIC"
 #' @param seed integer (default = 1), seed for random number generation (optional, see detail)
 #' @section Details:
-#' \code{cgr} is used to fit a Gaussian copula graphical model to multivariate discrete data, such as co-occurrence (multi species) data in ecology. The model is estimated using importance sampling with \code{n.samp} sets of randomised quantile or "Dunn-Smyth" residuals (Dunn & Smyth 1996), and the \code{\link{glasso}} package for fitting Gaussian graphical models. Models are fit for a path of values of the shrinkage parameter \code{lambda} chosen so that both completely dense and sparse models are fit. The \code{lambda} value for the \code{best_graph} is chosen by BIC (default) or AIC.  The seed is controlled so that models with the same data and different predictors can be compared.  
+#' \code{cgr} is used to fit a Gaussian copula graphical model to multivariate discrete data, such as co-occurrence (multi species) data in ecology. The model is estimated using importance sampling with \code{n.samp} sets of randomised quantile or "Dunn-Smyth" residuals (Dunn & Smyth 1996), and the \code{\link[glasso]{glasso}} function for fitting Gaussian graphical models. Models are fit for a path of values of the shrinkage parameter \code{lambda} chosen so that both completely dense and sparse models are fit. The \code{lambda} value for the \code{best_graph} is chosen by BIC (default) or AIC.  The seed is controlled so that models with the same data and different predictors can be compared.  
 #' @return Three objects are returned; 
 #' \code{best_graph} is a list with parameters for the 'best' graphical model, chosen by the chosen \code{method}; 
 #' \code{all_graphs} is a list with likelihood, BIC and AIC for all models along lambda path; 
@@ -30,10 +30,12 @@
 #' @section See also:
 #' \code{\link{plot.cgr}}
 #' @examples
+#' \donttest{
 #' abund <- spider$abund[,1:5]
 #' spider_mod <- stackedsdm(abund,~1, data = spider$x, ncores=2) 
 #' spid_graph=cgr(spider_mod)
 #' plot(spid_graph,pad=1)
+#' }
 #' @import mvabund
 #' @export 
 cgr <- function(obj, lambda = NULL, n.lambda = 100, 
@@ -76,7 +78,7 @@ cgr <- function(obj, lambda = NULL, n.lambda = 100,
     set.seed(seed)
     
     # simulate full set of residuals n.samp times
-    res = simulate.res.S(obj, n.res = n.samp)
+    res = simulate_res.S(obj, n.res = n.samp)
     
     #this chunk of code finds a path of lambda values to 
     #explore graphs ranging from completely sparse to completely dense.
