@@ -11,10 +11,12 @@ utils::globalVariables(c("cov2cor", "factanal", "weighted.mean","coef","plot",
 #' @param n.res number of residual sets to simulate
 #'
 #' @noRd
-simulate.res.S <- function(obj, n.res = 200) {
+simulate_res.S <- function(obj, n.res = 200) {
 
     many.obj = list(obj)[rep(1, n.res)]
-    res = plyr::llply(many.obj, residuals)
+    ## DW, 7.8.25: implementing suggestion https://github.com/gordy2x/ecoCopula/issues/19
+    #    res = plyr::llply(many.obj, residuals)
+    res = lapply(1:n.res,function(x) residuals(obj))
     res = plyr::llply(res, fix_inf)
     
     # residuals function for manyany currently output on uniform scale
@@ -171,7 +173,7 @@ check_object_family = function(object) {
 graph_from_partial<-function(partial){
     diag(partial)<-0
     vertex <- data.frame(name = colnames(partial))
-    Edges=igraph::as_data_frame(igraph::graph_from_adjacency_matrix(partial,mode="undirected",weighted = TRUE))
+    Edges=igraph::as_data_frame(igraph::graph_from_adjacency_matrix(partial,mode="max",weighted = TRUE))
     if(ncol(Edges)==3){
         colnames(Edges)[3]<- "partcor"
     }
